@@ -2,7 +2,7 @@ package Locale::CLDR::NumberFormatter;
 
 use version;
 
-our $VERSION = version->declare('v0.28.1');
+our $VERSION = version->declare('v0.32.0');
 
 
 use v5.10.1;
@@ -10,7 +10,7 @@ use mro 'c3';
 use utf8;
 use if $^V ge v5.12.0, feature => 'unicode_strings';
 
-use Moose::Role;
+use Moo::Role;
 
 sub format_number {
 	my ($self, $number, $format, $currency, $for_cash) = @_;
@@ -312,6 +312,9 @@ sub get_formatted_number {
 			my $pattern = "(A$minor_group)(A$major_group)*";
 			$number = reverse join $separator, grep {length} unpack $pattern, reverse $integer;
 		}
+		else {
+			$number = $integer;
+		}
 	}
 	else {
 		$number = $integer;
@@ -666,7 +669,7 @@ sub _get_algorithmic_number_format {
 	}
 }
 
-no Moose::Role;
+no Moo::Role;
 
 1;
 
